# Reference

::: kmService.KmResponse
    options:
      show_root_heading: true
      show_source: false

::: kmService.KmLintMeasure
    options:
      show_root_heading: true
      show_source: false

::: kmService.GeoCodeResponse
    options:
      show_root_heading: true
      show_source: false

::: kmService.KmLintResponse
    options:
      show_root_heading: true
      show_source: false
